
% loads XDF recorded during Meyendtris calibration phase,
% trains a standard CSP classifier using BCILAB, and starts
% writing continuous classification output to an instance of
% SNAP running on the same machine.

function onlineMeyendtris(subject)

EEG = pop_loadxdf(fullfile('C:\MeyendtrisData', sprintf('Meyendtris-%d-calibration.xdf', subject)));

approach = {'CSP' ...
        'SignalProcessing', { ...
            'FIRFilter', { ...
                'Frequencies', [6 8 14 16]} ...
            'EpochExtraction', { ...
                'TimeWindow', [0 1]}}};
                
[model, ~] = trainModel(EEG, approach, {'relax', 'chaos'}, 5, 5, 5, 5);

updateFreqLSL = 20;
updateFreqSNAP = 10;

run_readlsl( ...
        'MatlabStream', 'laststream', ...
        'DataStreamQuery', 'type=''EEG''', ...
        'MarkerQuery', 'name=''SNAP-Markers''', ...
        'UpdateFrequency', updateFreqLSL);

run_writesnap( ...
        'Model', model, ...
        'SourceStream', 'laststream', ...
        'OutputHost', 'localhost', ...
        'UpdateFrequency', updateFreqSNAP, ...
        'Verbose', true);

end
